



if not exist %PREFIX%\\Library\\include\\gnuradio\\inspector\\api.h exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\bin\\gnuradio-inspector.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\lib\\gnuradio-inspector.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\share\\gnuradio\\grc\\blocks\\inspector_ofdm_synchronizer_cc.block.yml exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\share\\gnuradio\\grc\\blocks\\inspector_ofdm_zkf_c.block.yml exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\share\\gnuradio\\grc\\blocks\\inspector_qtgui_inspector_sink_vf.block.yml exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\share\\gnuradio\\grc\\blocks\\inspector_signal_detector_cvf.block.yml exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\share\\gnuradio\\grc\\blocks\\inspector_signal_extractor_c.block.yml exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\share\\gnuradio\\grc\\blocks\\inspector_signal_separator_c.block.yml exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
